@@ -16,7 +16,7 @@ def cli(ctx, state, nodes, volumes, http_port):
     deploy(ctx, state, nodes, volumes, http_port, "latest", "setup")
     ctx.log("\n%s\n" % ("*" * 72))
     ctx.log("API        : http://localhost:%s/oarapi/" % http_port)
-    ctx.log("Monika     : http://localhost:%s/monika" % http_port)
-    ctx.log("Drawgantt  : http://localhost:%s/drawgantt-svg" % http_port)
-    ctx.log("PhpPgAdmin : http://localhost:%s/phppgadmin" % http_port)
+    ctx.log("Monika     : http://localhost:%s/monika/" % http_port)
+    ctx.log("Drawgantt  : http://localhost:%s/drawgantt-svg/" % http_port)
+    ctx.log("PhpPgAdmin : http://localhost:%s/phppgadmin/" % http_port)
     ctx.log("\n%s\n" % ("*" * 72))
